Enum PropertiesBufError
#[non_exhaustive]pub enum PropertiesBufError {
DisallowedProperty(PropertyId),
DuplicateProperty(PropertyId),
TooLong,
}Expand description
Error returned by fallible mutation methods on PropertiesBuf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DisallowedProperty(PropertyId)
The supplied property’s identifier is not permitted by the
PropertyConstraint.
DuplicateProperty(PropertyId)
The buffer already holds a property with this identifier and it may appear at most once (Protocol Error when sent, 2.2.2.2).
TooLong
Appending the property would push the total encoded length above
Vbi::MAX.